from viktor import ViktorController
from viktor.parametrization import ViktorParametrization, OptionField
from viktor.views import PlotlyView, PlotlyResult

import plotly.express as px


class Parametrization(ViktorParametrization):
    _options = ["The Netherlands", "Continents", "Global"]
    graph = OptionField("Life expectancy:", options=_options, default="Continents", variant="radio", flex=100)


class Controller(ViktorController):
    label = 'My Entity Type'
    parametrization = Parametrization(width=20)

    @PlotlyView("Life Expectancy", duration_guess=3)
    def plotly_view(self, params, **kwargs):
        dataframe = px.data.gapminder()
        if params.graph == 'The Netherlands':
            data = dataframe.query("country == 'Netherlands' ")
            fig = px.bar(data, x='year', y='pop', color='lifeExp')
        elif params.graph == 'Continents':
            fig = px.scatter(dataframe, x="gdpPercap", y="lifeExp", animation_frame="year", animation_group="country",
                             size="pop", color="continent", hover_name="country", facet_col="continent",
                             log_x=True, size_max=75, range_x=[100, 100000], range_y=[25, 90])
        elif params.graph == 'Global':
            fig = px.choropleth(dataframe, locations='iso_alpha', color='lifeExp', hover_name='country',
                                animation_frame='year', color_continuous_scale=px.colors.sequential.Plasma,
                                projection='natural earth')
        else:
            raise NotImplementedError
        return PlotlyResult(fig.to_json())
